# eric7.EricWidgets.EricAnimatedLabel

Module implementing a label widget showing an animated pixmap.

### Global Attributes

None

### Classes

EricAnimatedLabel | Class implementing a label widget showing an animated pixmap.

### Functions

None

## EricAnimatedLabel

Class implementing a label widget showing an animated pixmap.

### Derived from

QLabel

### Class Attributes

None

### Class Methods

None

### Methods

EricAnimatedLabel | Constructor
__animate | Private slot to animate the pixmap.
__loadAnimationFile | Private method to load an animation file.
getAnimationFile | Public method to get the name of the animation file.
getInterval | Public method to get the interval between the animated frames.
isActive | Public method to check, if the animation is active.
isAnimationFileLoaded | Public method to check, if the animation file was loaded.
reset | Public slot to reset the animation.
setAnimationFile | Public method to set the name of the animation file.
setInterval | Public method to set the interval between the animated frames.
setPixmap | Public slot to set the pixmap of the label.
start | Public slot to start the animation.
stop | Public slot to stop the animation.

### Static Methods

None

#### EricAnimatedLabel (Constructor)

EricAnimatedLabel(parent=None, *, animationFile="", interval=100)

Constructor

parent (QWidget)
  reference to the parent window
animationFile= (str)
  path to the file containing the animation data
interval= (int)
  interval in milliseconds between animation frames

#### EricAnimatedLabel.__animate

__animate()

Private slot to animate the pixmap.

#### EricAnimatedLabel.__loadAnimationFile

__loadAnimationFile(animationFile)

Private method to load an animation file.

animationFile (str)
  path to the file containing the animation data

#### EricAnimatedLabel.getAnimationFile

getAnimationFile()

Public method to get the name of the animation file.

Return:
  path to the file containing the animation data

Return Type:
  str

#### EricAnimatedLabel.getInterval

getInterval()

Public method to get the interval between the animated frames.

Return:
  interval in milliseconds between animation frames

Return Type:
  int

#### EricAnimatedLabel.isActive

isActive()

Public method to check, if the animation is active.

Return:
  flag indicating an active animation

Return Type:
  bool

#### EricAnimatedLabel.isAnimationFileLoaded

isAnimationFileLoaded()

Public method to check, if the animation file was loaded.

Return:
  flag indicating a successfully loaded animation file

Return Type:
  bool

#### EricAnimatedLabel.reset

reset()

Public slot to reset the animation.

#### EricAnimatedLabel.setAnimationFile

setAnimationFile(animationFile)

Public method to set the name of the animation file.

animationFile (str)
  path to the file containing the animation data

#### EricAnimatedLabel.setInterval

setInterval(interval)

Public method to set the interval between the animated frames.

interval (int)
  interval in milliseconds between animation frames

#### EricAnimatedLabel.setPixmap

setPixmap(pixmap)

Public slot to set the pixmap of the label.

Setting a standard pixmap will stop the animation and set the given pixmap without animating it. Thereafter the animation has to be restarted with the start() method.

pixmap (QPixmap)
  pixmap to be set

#### EricAnimatedLabel.start

start()

Public slot to start the animation.

#### EricAnimatedLabel.stop

stop()

Public slot to stop the animation.

Up